
# Slot: description




URI: [biolink:entity_to_phenotypic_feature_association_description](https://w3id.org/biolink/vocab/entity_to_phenotypic_feature_association_description)

## Domain and Range

[EntityToPhenotypicFeatureAssociation](EntityToPhenotypicFeatureAssociation.md) ->  <sub>OPT</sub> [NarrativeText](NarrativeText.md)

## Parents

 *  is_a: [description](description.md)

## Children


## Used by

 * [EntityToPhenotypicFeatureAssociation](EntityToPhenotypicFeatureAssociation.md)
